require 'helper'
require 'airgun'

describe Airgun do

  it 'should handle basic html compression' do
    r = Airgun::html 'spec/resources/test1.htm'
    r.should_not == nil
    r.include?('16').should == false
  end

  it 'should run erb' do
    a = {
      :erb => true
    }
    r = Airgun::html 'spec/resources/test1.htm', a
    r.include?('64').should == true
  end

  it 'should handle embedded and linked css compression' do
    a = {
      :erb => true
    }
    r = Airgun::html 'spec/resources/test2.htm', a
    r.include?('64').should == true
    r.include?('#one').should == true
    r.include?('#four').should == true
  end

  it 'should handle embedded js and linked js with Closure' do
    a = {
      :erb => true,
      :compressor => :closure
    }
    r = Airgun::html 'spec/resources/test3.htm', a
    r.include?('64').should == true
    r.include?('alert("one")').should == true
    r.include?('alert("two")').should == true
  end

  it 'should handle embedded and linked js with YUI' do
    a = {
      :erb => false,
      :compressor => :yui
    }
    r = Airgun::html 'spec/resources/test3.htm', a
    r.include?('64').should == false
    r.include?('alert("one")').should == true
    r.include?('alert("two")').should == true
  end

  it 'should handle direct css with file write' do
    fname = '/tmp/compressed.css'
    File.delete fname if File.exist? fname

    a = {
      :outfile => fname
    }

    Airgun::css 'spec/resources/css/test2.css', a

    content = File.open(fname) { |f| f.read }
    content.include?('#four').should == true
  end

  it 'should handle direct js with file write' do
    fname = '/tmp/compressed.js'
    File.delete fname if File.exist? fname

    a = {
      :outfile => fname
    }

    Airgun::js 'spec/resources/js/test3.js', a

    content = File.open(fname) { |f| f.read }
    content.include?('alert("two")').should == true
  end

end

